/***********************************************************************
*
* Copyright (c) 2021-2023 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
   CS_OBJECT(MainWindow)

 public:
   MainWindow();

 protected:
   void changeEvent(QEvent *event) override;

 private:
   void setLanguage(const QString language);
   void retranslate_UI();

   QRadioButton *rb0;
   QRadioButton *rb1;
   QRadioButton *rb2;
   QRadioButton *rb3;
   QRadioButton *rb4;
   QRadioButton *rb5;
   QRadioButton *rb6;

   QPushButton *english_pb;
   QPushButton *german_pb;
   QPushButton *close_pb;

   QTranslator *m_translator;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 300);

   rb0 = new QRadioButton;
   rb1 = new QRadioButton;
   rb2 = new QRadioButton;
   rb3 = new QRadioButton;
   rb4 = new QRadioButton;
   rb5 = new QRadioButton;
   rb6 = new QRadioButton;

   QVector<QRadioButton *> list = {rb0, rb1, rb2, rb3, rb4, rb5, rb6};

   for (auto item : list) {
      QFont font = item->font();
      font.setPointSize(11);
      item->setFont(font);
   }

   english_pb = new QPushButton();
   german_pb  = new QPushButton();
   close_pb   = new QPushButton();

   QGridLayout *grid = new QGridLayout();
   grid->setContentsMargins(75, 35, 75, 25);
   grid->setHorizontalSpacing(20);
   grid->setVerticalSpacing(30);

   grid->addWidget(rb0, 0, 0);
   grid->addWidget(rb1, 1, 0);
   grid->addWidget(rb2, 2, 0);
   grid->addWidget(rb3, 3, 0);
   grid->addWidget(rb4, 4, 0);
   grid->addWidget(rb5, 5, 0);
   grid->addWidget(rb6, 6, 0);

   QHBoxLayout *layout_pb = new QHBoxLayout();
   layout_pb->addStretch();
   layout_pb->addWidget(english_pb);
   layout_pb->addSpacing(20);
   layout_pb->addWidget(german_pb);
   layout_pb->addSpacing(20);
   layout_pb->addWidget(close_pb);
   layout_pb->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid);
   layoutMain->addSpacing(50);
   layoutMain->addLayout(layout_pb);

   connect(english_pb, &QPushButton::clicked, this, [this] () { setLanguage("english.qm"); });
   connect(german_pb,  &QPushButton::clicked, this, [this] () { setLanguage("german.qm");  });
   connect(close_pb,   &QPushButton::clicked, this, &QWidget::close);

   m_translator = new QTranslator;
   retranslate_UI();
}

void MainWindow::setLanguage(const QString language)
{
   static const QString qmPath = QApplication::applicationDirPath();

   if (m_translator->load(language, qmPath)) {
      QApplication::instance()->installTranslator(m_translator);
   } else {
      QMessageBox::warning(this, tr("Example 37"), tr("Unable to load translation file: ") + language);
   }
}

void MainWindow::changeEvent(QEvent *event)
{
   if (event->type() == QEvent::LanguageChange) {
      retranslate_UI();
   }

   QWidget::changeEvent(event);
}

void MainWindow::retranslate_UI()
{
   rb0->setText(tr("Sunday"));
   rb1->setText(tr("Monday"));
   rb2->setText(tr("Tuesday"));
   rb3->setText(tr("Wednesday"));
   rb4->setText(tr("Thursday"));
   rb5->setText(tr("Friday"));
   rb6->setText(tr("Saturday"));

   english_pb->setText(tr("English"));
   german_pb->setText(tr("German"));
   close_pb->setText(tr("Close"));
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
